Style

Struct Style 

pub struct Style { /* private fields */ }
Text formatting styles.

Examples

use tty_interface::{Color, Style};

let style = Color::Red.as_style().set_bold(true);

Implementations

Source

impl Style

pub fn new() -> Self

Create a new style with no colors or styling.

pub fn set_foreground(&self, color: Color) -> Style

Create a new style with the specified foreground color.

pub fn foreground(&self) -> Option<Color>

This style’s foreground color, if specified.

pub fn set_background(&self, color: Color) -> Style

Create a new style with the specified background color.

pub fn background(&self) -> Option<Color>

This style’s background color, if specified.

pub fn set_bold(&self, is_bold: bool) -> Style

Create a new style with the specified bold value.

pub fn is_bold(&self) -> bool

Whether this style is bolded.

pub fn set_italic(&self, is_italic: bool) -> Style

Create a new style with the specified italic value.

pub fn is_italic(&self) -> bool

Whether this style is italicized.

pub fn set_underline(&self, is_underline: bool) -> Style

Create a new style with the specified underline value.

pub fn is_underlined(&self) -> bool

Whether this style is underlined.