Module tty_interface::result [−][src]
Enums
A specialized error type encompassing tty-interface and std::io::Error errors.
Type Definitions
A specialized result type encompassing errors from the tty-interface crate and std::io.
A specialized error type encompassing tty-interface and std::io::Error errors.
A specialized result type encompassing errors from the tty-interface crate and std::io.