Trait tty_interface::Device

source ·
pub trait Device: Write {
    fn get_terminal_size(&mut self) -> Result<Vector>;
    fn enable_raw_mode(&mut self) -> Result<()>;
    fn disable_raw_mode(&mut self) -> Result<()>;
    fn get_cursor_position(&mut self) -> Result<Position>;
}
An output device to be controlled for displaying an interface.

Required Methods

Retrieve the device’s terminal viewport size.

Enable “raw mode” in the terminal.

Restore the configuration before the terminal was placed in “raw mode”.

Retrieve the cursor’s absolute position in the device’s buffer.

Implementations on Foreign Types

Implementors